@@ -39,15 +39,7 @@ def format_plan(build, tests):
     else:
         raise NotImplementedError()
 
-    builds = (
-        build.uid
-        + " "
-        + f"{icon} {color}{message}{colors.reset}"
-        + " "
-        + build.target_arch
-        + "@"
-        + build.toolchain
-    )
+    builds = build.get_builds_message(icon, color, message)
 
     tests_str = ""
     tests_pass = sorted(
@@ -111,11 +103,16 @@ def handle_get(options, config):
 
     start_builds = data["builds"]["next"]
     start_tests = data["tests"]["next"]
-    while start_builds or start_tests:
+    start_oebuilds = data["oebuilds"]["next"]
+    while start_builds or start_tests or start_oebuilds:
         ret = get(
             config,
             f"/v1/groups/{config.group}/projects/{config.project}/plans/{options.uid}",
-            params={"start_builds": start_builds, "start_tests": start_tests},
+            params={
+                "start_builds": start_builds,
+                "start_tests": start_tests,
+                "start_oebuilds": start_oebuilds,
+            },
         )
         if ret.status_code != 200:
             raise NotImplementedError()
@@ -127,6 +124,9 @@ def handle_get(options, config):
         if start_tests:
             data["tests"]["results"].extend(datan["tests"]["results"])
             start_tests = datan["tests"]["next"]
+        if start_oebuilds:
+            data["oebuilds"]["results"].extend(datan["oebuilds"]["results"])
+            start_oebuilds = datan["oebuilds"]["next"]
 
     plan = Plan.new(**data)
     if options.json:
@@ -144,7 +144,7 @@ def handle_get(options, config):
         for test in [t for t in plan.tests if t.waiting_for is None]:
             print(format_test(test))
 
-        bs = f"builds ({len(plan.builds)}):"
+        bs = f"builds ({len(plan.all_builds)}):"
         provisioning = len(plan.filter_builds(lambda _, b: b.state == "provisioning"))
         running = len(plan.filter_builds(lambda _, b: b.state == "running"))
         passing = len(
